searchData={"items":[{"type":"module","title":"O11y","doc":"A module to help with OpenTelemetry tracing.","ref":"O11y.html"},{"type":"function","title":"O11y.attach_distributed_trace_ctx/1","doc":"This is the counterpart to `get_distributed_trace_ctx/0`. It is used to \"extract\" trace context information from http headers.\nThis context information is stored in a string so it can be passed around by other means as well.","ref":"O11y.html#attach_distributed_trace_ctx/1"},{"type":"function","title":"Examples: - O11y.attach_distributed_trace_ctx/1","doc":"```elixir\niex> O11y.attach_distributed_trace_ctx([traceparent: \"00-0af7651916cd43dd8448eb211c80319c-b7ad6b7169203331-01\"])\niex> O11y.attach_distributed_trace_ctx(\"00-0af7651916cd43dd8448eb211c80319c-b7ad6b7169203331-01\")\niex> O11y.attach_distributed_trace_ctx(nil)\n```","ref":"O11y.html#attach_distributed_trace_ctx/1-examples"},{"type":"function","title":"O11y.end_span/1","doc":"Ends the current span and marks the given parent span as current.","ref":"O11y.html#end_span/1"},{"type":"function","title":"Examples: - O11y.end_span/1","doc":"```elixir\niex> span = O11y.start_span(\"checkout\")\niex> O11y.end_span(span)\n```","ref":"O11y.html#end_span/1-examples"},{"type":"function","title":"O11y.get_distributed_trace_ctx/0","doc":"This function is typically used to \"inject\" trace context information into http headers such that\nthe trace can be continued in another service. However, it can also be used to link span in cases where\nOpenTelemetry.Ctx.attach/1 will not work (such as when the parent span has already ended or been removed from the dictionary).","ref":"O11y.html#get_distributed_trace_ctx/0"},{"type":"function","title":"Examples: - O11y.get_distributed_trace_ctx/0","doc":"```elixir\niex> res = Tracer.with_span \"some_span\", do: O11y.get_distributed_trace_ctx()\niex> [{\"traceparent\", _}] = res\n```","ref":"O11y.html#get_distributed_trace_ctx/0-examples"},{"type":"function","title":"O11y.record_exception/1","doc":"Records an exception and sets the status of the current span to error.","ref":"O11y.html#record_exception/1"},{"type":"function","title":"Examples: - O11y.record_exception/1","doc":"```elixir\niex> O11y.record_exception(%RuntimeError{message: \"something went wrong\"})\n%RuntimeError{message: \"something went wrong\"}\n```\n\nProduces a span like:\n```elixir\n{:span, 28221055821181380594370570739471883760, 5895012157721301439, [],\n  :undefined, \"checkout\", :internal, -576460751313205167, -576460751311430083,\n  {:attributes, 128, :infinity, 0, %{}},\n  {:events, 128, 128, :infinity, 0,\n  [\n    {:event, -576460751311694042, \"exception\",\n     {:attributes, 128, :infinity, 0,\n      %{\n        \"exception.message\": \"something went wrong\",\n        \"exception.stacktrace\": \"...\",\n        \"exception.type\": \"Elixir.RuntimeError\"\n      }}}\n  ]}, {:links, 128, 128, :infinity, 0, []}, {:status, :error, \"\"}, 1, false,\n  :undefined}\n```","ref":"O11y.html#record_exception/1-examples"},{"type":"function","title":"O11y.set_attribute/3","doc":"Sets the given attribute on the current span. If the value is not a valid OTLP type,\nit will be converted to a string with `inspect`.\n\nThis method does not support structs to maps, regardless of whether the struct implements the O11y.SpanAttributes protocol.\nYou need to use `set_attributes/1` for that.","ref":"O11y.html#set_attribute/3"},{"type":"function","title":"Examples: - O11y.set_attribute/3","doc":"```elixir\niex> O11y.set_attribute(\"key\", \"value\")\n:ok\n\n# Produces span attributes like:\n{:attributes, 128, :infinity, 0, %{key: \"value\"}}\n```\n\n```elixir\niex> O11y.set_attribute(\"key\", \"value\", namespace: \"cool_app\")\n:ok\n\n# Produces span attributes like:\n{:attributes, 128, :infinity, 0, %{\"cool_app.key\" => \"value\"}}\n```\n\nNamespace can also be set globally via configuration like:\n```elixir\nconfig :open_telemetry_decorator, :attribute_namespace, \"app\"\n```","ref":"O11y.html#set_attribute/3-examples"},{"type":"function","title":"O11y.set_attributes/2","doc":"Adds the given attributes as a list, map, or struct to the current span.\nIf the value is a maps or struct, it will be converted to a list of key-value pairs.\nIf the struct derives the O11y.SpanAttributes protocol, it will honor the except and only options.","ref":"O11y.html#set_attributes/2"},{"type":"function","title":"Examples: - O11y.set_attributes/2","doc":"```elixir\niex> O11y.set_attributes(%{id: 123, name: \"Alice\"})\n%{id: 123, name: \"Alice\"}\n\n# Produces span attributes like:\n{:attributes, 128, :infinity, 0, %{id: 123, name: \"Alice\"}}\n```\n\n```elixir\niex> O11y.set_attributes(%{name: \"Steve\", age: 47}, prefix: \"user\")\n%{name: \"Steve\", age: 47}\n\n# Produces span attributes like:\n{:attributes, 128, :infinity, 0, %{\"user.age\" => 47, \"user.name\" => \"Steve\"}}\n```\n\n```elixir\niex> O11y.set_attributes(%{name: \"Steve\", age: 47}, namespace: \"app\")\n%{name: \"Steve\", age: 47}\n\n# Produces span attributes like:\n{:attributes, 128, :infinity, 0, %{\"app.age\" => 47, \"app.name\" => \"Steve\"}}\n```\n\nNamespace can also be set globally via configuration like:\n```elixir\nconfig :open_telemetry_decorator, :attribute_namespace, \"app\"\n```","ref":"O11y.html#set_attributes/2-examples"},{"type":"function","title":"O11y.set_error/0","doc":"Sets the status of the current span to error","ref":"O11y.html#set_error/0"},{"type":"function","title":"O11y.set_error/1","doc":"Sets the status of the current span to error, and sets an error message.\n\n# Examples:\n\n```elixir\niex> O11y.set_error(\"something went wrong\")\n\"something went wrong\"\n```\n\n```elixir\niex> O11y.set_error(%RuntimeError{message: \"something went wrong\"})\n%RuntimeError{message: \"something went wrong\"}\n```\n\n```elixir\niex> O11y.set_error(%Jason.DecodeError{position: 0, token: nil, data: \"\"})\n%Jason.DecodeError{position: 0, token: nil, data: \"\"}\n```","ref":"O11y.html#set_error/1"},{"type":"function","title":"O11y.start_span/2","doc":"Starts a new span and makes it the current active span of the current process.\n\nThis is a little tricky because it actually returns the parent span, not the new span.\nHowever, this is because we want to be able to end the span and set the current span back to the parent which is not the default behavior.\nThe API `end_span` function doesn't take a span to end anyway (though it seems like it should)\nso you sort of use this as I would expect the actual API to work and get similar behavior to `with_span`","ref":"O11y.html#start_span/2"},{"type":"function","title":"Examples: - O11y.start_span/2","doc":"```elixir\niex> Tracer.with_span \"checkout\" do\niex>  parent = O11y.start_span(\"calculate_tax\")\niex>  # gnarly_calculations()\niex>  O11y.end_span(parent)\niex> end\n```","ref":"O11y.html#start_span/2-examples"},{"type":"module","title":"O11y.AttributeProcessor","doc":"Functions for manipulating attribute names","ref":"O11y.AttributeProcessor.html"},{"type":"function","title":"O11y.AttributeProcessor.prefix/2","doc":"","ref":"O11y.AttributeProcessor.html#prefix/2"},{"type":"function","title":"O11y.AttributeProcessor.trim_leading/1","doc":"","ref":"O11y.AttributeProcessor.html#trim_leading/1"},{"type":"module","title":"O11y.Attributes","doc":"This is more of a convenience module since the attributes that the record wraps are a plain map.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/c1ccdffb11253f5da63146a6c014db41bb4b27cc/apps/opentelemetry_api/src/otel_attributes.erl#L37","ref":"O11y.Attributes.html"},{"type":"function","title":"O11y.Attributes.from_record/1","doc":"Builds a map from the given attribute record.","ref":"O11y.Attributes.html#from_record/1"},{"type":"function","title":"Examples - O11y.Attributes.from_record/1","doc":"```elixir\niex> O11y.Attributes.from_record({:attributes, 128, :infinity, 0, %{key: \"value\"}})\n%{key: \"value\"}\n```","ref":"O11y.Attributes.html#from_record/1-examples"},{"type":"macro","title":"O11y.Attributes.is_otlp_value/1","doc":"","ref":"O11y.Attributes.html#is_otlp_value/1"},{"type":"function","title":"O11y.Attributes.to_record/1","doc":"","ref":"O11y.Attributes.html#to_record/1"},{"type":"type","title":"O11y.Attributes.attributes_record/0","doc":"","ref":"O11y.Attributes.html#t:attributes_record/0"},{"type":"type","title":"O11y.Attributes.t/0","doc":"","ref":"O11y.Attributes.html#t:t/0"},{"type":"module","title":"O11y.Event","doc":"Struct version of the erlang record definition for an event.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/include/otel_span.hrl#L81","ref":"O11y.Event.html"},{"type":"function","title":"O11y.Event.from_record/1","doc":"Builds an event struct from the given record.","ref":"O11y.Event.html#from_record/1"},{"type":"function","title":"Examples - O11y.Event.from_record/1","doc":"```elixir\niex> O11y.Event.from_record({:event, 1, \"event_name\", {:attributes, 128, :infinity, 0, %{key: \"value\"}}})\n%O11y.Event{\n  name: \"event_name\",\n  native_time: 1,\n  attributes: %{key: \"value\"}\n}\n```","ref":"O11y.Event.html#from_record/1-examples"},{"type":"type","title":"O11y.Event.event_record/0","doc":"","ref":"O11y.Event.html#t:event_record/0"},{"type":"type","title":"O11y.Event.t/0","doc":"","ref":"O11y.Event.html#t:t/0"},{"type":"module","title":"O11y.Events","doc":"Struct version of the erlang record definition for the events record on a span.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/src/otel_events.erl#L27","ref":"O11y.Events.html"},{"type":"function","title":"O11y.Events.from_record/1","doc":"Builds a list of event structs from the given record.","ref":"O11y.Events.html#from_record/1"},{"type":"function","title":"Examples - O11y.Events.from_record/1","doc":"```elixir\niex> O11y.Events.from_record({:events, 128, 128, :infinity, 0, [{:event, 1, \"event_name\", {:attributes, 128, :infinity, 0, %{key: \"value\"}}}]})\n[%O11y.Event{\n  name: \"event_name\",\n  native_time: 1,\n  attributes: %{key: \"value\"}\n}]\n```","ref":"O11y.Events.html#from_record/1-examples"},{"type":"type","title":"O11y.Events.events_record/0","doc":"","ref":"O11y.Events.html#t:events_record/0"},{"type":"type","title":"O11y.Events.t/0","doc":"","ref":"O11y.Events.html#t:t/0"},{"type":"module","title":"O11y.Link","doc":"Struct version of the erlang record definition for a link.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/include/otel_span.hrl#L74","ref":"O11y.Link.html"},{"type":"function","title":"O11y.Link.from_record/1","doc":"Builds a link struct from the given record.","ref":"O11y.Link.html#from_record/1"},{"type":"function","title":"Examples - O11y.Link.from_record/1","doc":"```elixir\niex> O11y.Link.from_record({:link, 128, 128, {:attributes, 128, :infinity, 0, %{key: \"value\"}}, []})\n%O11y.Link{\n  trace_id: 128,\n  span_id: 128,\n  attributes: %{key: \"value\"},\n  tracestate: []\n}\n```","ref":"O11y.Link.html#from_record/1-examples"},{"type":"type","title":"O11y.Link.link_record/0","doc":"","ref":"O11y.Link.html#t:link_record/0"},{"type":"type","title":"O11y.Link.t/0","doc":"","ref":"O11y.Link.html#t:t/0"},{"type":"module","title":"O11y.Links","doc":"Struct version of the erlang record definition for the links record on a span.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/src/otel_links.erl#L27","ref":"O11y.Links.html"},{"type":"function","title":"O11y.Links.from_record/1","doc":"Builds a list of link structs from the given record.","ref":"O11y.Links.html#from_record/1"},{"type":"function","title":"Examples - O11y.Links.from_record/1","doc":"```elixir\niex> O11y.Links.from_record({:links, 128, 128, :infinity, 0, [{:link, 128, 128, {:attributes, 128, :infinity, 0, %{key: \"value\"}}, []}]})\n[%O11y.Link{\n  trace_id: 128,\n  span_id: 128,\n  attributes: %{key: \"value\"},\n  tracestate: []\n}]\n```","ref":"O11y.Links.html#from_record/1-examples"},{"type":"type","title":"O11y.Links.links_record/0","doc":"","ref":"O11y.Links.html#t:links_record/0"},{"type":"type","title":"O11y.Links.t/0","doc":"","ref":"O11y.Links.html#t:t/0"},{"type":"module","title":"O11y.RecordDefinitions","doc":"This is a convenience module for defining the records from the OpenTelemetry Erlang library.\n\nPull it in and use it like:\n\n```elixir\ndefmodule SomeTest do\n  use ExUnit.Case, async: true\n  use O11y.RecordDefinitions\n\n  test \"building spans for some reason\" do\n    span_record = span(name: \"do it!\", trace_id: 123, span_id: 456)\n    dbg(span_record)\n  end\nend\n```","ref":"O11y.RecordDefinitions.html"},{"type":"module","title":"O11y.Span","doc":"Struct version of the erlang record definition for span, along with its dependent entities.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/include/otel_span.hrl#L19","ref":"O11y.Span.html"},{"type":"function","title":"O11y.Span.from_record/1","doc":"Builds a Span struct with all its properties filled out from the given record.","ref":"O11y.Span.html#from_record/1"},{"type":"function","title":"Examples: - O11y.Span.from_record/1","doc":"```elixir\niex> span_record =\niex> {\n...>   :span,\n...>   36028033703494123531935328165008164641,\n...>   3003871636294788166,\n...>   [],\n...>   9251127051694223323,\n...>   \"span3\",\n...>   :internal,\n...>   -576460751554471834,\n...>   -576460751554453625,\n...>   {:attributes, 128, :infinity, 0, %{attr2: \"value2\"}},\n...>   {:events, 128, 128, :infinity, 0,\n...>     [\n...>       {:event, -576460751554458125, \"event1\",\n...>       {:attributes, 128, :infinity, 0, %{attr3: \"value3\"}}}\n...>     ]},\n...>   {:links, 128, 128, :infinity, 0,\n...>     [\n...>       {:link, 15885629928321603655903684450721700386,\n...>       4778191783967788040,\n...>       {:attributes, 128, :infinity, 0, %{link_attr1: \"link_value1\"}}, []}\n...>     ]},\n...>   {:status, :error, \"whoops!\"},\n...>   1,\n...>   true,\n...>   :undefined\n...> }\niex> Span.from_record(span_record)\niex> %O11y.Span{\n...>   trace_id: 36028033703494123531935328165008164641,\n...>   span_id: 3003871636294788166,\n...>   tracestate: [],\n...>   parent_span_id: 9251127051694223323,\n...>   name: \"span3\",\n...>   kind: :internal,\n...>   start_time: -576460751554471834,\n...>   end_time: -576460751554453625,\n...>   duration_ms: 0,\n...>   attributes: %{attr2: \"value2\"},\n...>   events: [\n...>     %O11y.Event{\n...>       name: \"event1\",\n...>       native_time: -576460751554458125,\n...>       attributes: %{attr3: \"value3\"}\n...>     }\n...>   ],\n...>   links: [\n...>     %O11y.Link{\n...>       trace_id: 15885629928321603655903684450721700386,\n...>       span_id: 4778191783967788040,\n...>       attributes: %{link_attr1: \"link_value1\"},\n...>       tracestate: []\n...>     }\n...>   ],\n...>   status: %O11y.Status{code: :error, message: \"whoops!\"},\n...>   trace_flags: 1,\n...>   is_recording: true,\n...>   instrumentation_scope: :undefined\n...> }\n```","ref":"O11y.Span.html#from_record/1-examples"},{"type":"macro","title":"O11y.Span.is_span_record/1","doc":"Guard definition for the from_record function.","ref":"O11y.Span.html#is_span_record/1"},{"type":"type","title":"O11y.Span.span_kind/0","doc":"","ref":"O11y.Span.html#t:span_kind/0"},{"type":"type","title":"O11y.Span.span_record/0","doc":"","ref":"O11y.Span.html#t:span_record/0"},{"type":"type","title":"O11y.Span.t/0","doc":"","ref":"O11y.Span.html#t:t/0"},{"type":"protocol","title":"O11y.SpanAttributes","doc":"Defines a protocol for returning opentelemetry span attributes from an object.\nThe easiest way to use this is to use the `@derive` attribute on a struct as shown below,\nbut you can also implement the protocol manually if you need to define custom behavior.\n\nWith the basic derive, all fields in the struct will be returned as attributes:\n```elixir\ndefmodule Basic do\n  @derive O11y.SpanAttributes\n  defstruct [:id, :name]\nend\n```\n\nYou can also use the `only` and `except` options to include or exclude specific fields:\n```elixir\ndefmodule Only do\n  @derive {O11y.SpanAttributes, only: [:id, :name]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\n```elixir\ndefmodule Except do\n  @derive {O11y.SpanAttributes, except: [:email, :password]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\nOr you can manually implement the protocol for a struct:\n```elixir\ndefmodule Fancy do\n  defstruct [:url, :token]\nend\n\ndefimpl O11y.SpanAttributes, for: Fancy do\n  def get(%{url: url, token: token}) do\n    masked_token = token |> String.slice(-4, 4) |> String.pad_leading(String.length(token), \"*\")\n    [{\"url\", url}, {\"token\", masked_token}]\n  end\nend\n```","ref":"O11y.SpanAttributes.html"},{"type":"function","title":"O11y.SpanAttributes.get/1","doc":"Returns the opentelemetry span attributes for the given object as a list of tuples.","ref":"O11y.SpanAttributes.html#get/1"},{"type":"type","title":"O11y.SpanAttributes.otlp_value/0","doc":"","ref":"O11y.SpanAttributes.html#t:otlp_value/0"},{"type":"type","title":"O11y.SpanAttributes.t/0","doc":"All the types that implement this protocol.","ref":"O11y.SpanAttributes.html#t:t/0"},{"type":"module","title":"O11y.Status","doc":"Struct version of the erlang record definition for the status record on a span.\n\nThe record is defined here:\nhttps://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry_api/include/opentelemetry.hrl#L76","ref":"O11y.Status.html"},{"type":"function","title":"O11y.Status.from_record/1","doc":"Builds a status struct from the given record.","ref":"O11y.Status.html#from_record/1"},{"type":"function","title":"Examples - O11y.Status.from_record/1","doc":"```elixir\niex> O11y.Status.from_record({:status, :error, \"whoops!\"})\n%O11y.Status{\n  code: :error,\n  message: \"whoops!\"\n}\n```","ref":"O11y.Status.html#from_record/1-examples"},{"type":"type","title":"O11y.Status.status_record/0","doc":"","ref":"O11y.Status.html#t:status_record/0"},{"type":"type","title":"O11y.Status.t/0","doc":"","ref":"O11y.Status.html#t:t/0"},{"type":"behaviour","title":"O11y.TestHelper","doc":"Provides a few helper functions to make testing with OpenTelemetry easier.","ref":"O11y.TestHelper.html"},{"type":"behaviour","title":"Examples: - O11y.TestHelper","doc":"```elixir\ndefmodule MyTest do\n  use ExUnit.Case, async: true\n  use O11y.TestHelper\n\n  test \"appends the given attribute to the span\" do\n    Tracer.with_span \"checkout\" do\n      O11y.set_attribute(:id, 123)\n    end\n\n    assert_span(\"checkout\", attributes: %{id: 123})\n  end\nend\n```","ref":"O11y.TestHelper.html#module-examples"},{"type":"callback","title":"O11y.TestHelper.assert_span/2","doc":"Asserts that a span with the given name was exported and optionally checks the status and attributes.","ref":"O11y.TestHelper.html#c:assert_span/2"},{"type":"callback","title":"Examples: - O11y.TestHelper.assert_span/2","doc":"```elixir\nassert_span(\"checkout\", attributes: %{\"id\" => 123})\nassert_span(\"checkout\", status: :error)\n```\n\nIt returns the matched span record so you can make additional assertions. The easiest way is to pattern match by creating a span record and bind the properties you want to assert on.\nYou can use the included span, link, and event records to help with this, as well as the status, links, events, and attributes functions.\n\nExamples:\n```elixir\nspan(status: status, events: events) = assert_span(\"checkout\")\n\nassert status(status) == :error\nassert [event(name: \"exception\", attributes: attributes)] = events(events)\nassert %{\"exception.message\": \"something went wrong\"} = attributes(attributes)\n```","ref":"O11y.TestHelper.html#c:assert_span/2-examples"},{"type":"callback","title":"O11y.TestHelper.otel_pid_reporter/1","doc":"Sets up OpenTelemetry to use the pid exporter and ensures it is stopped after the test.\nWhen spans are exported, a message is sent to the test pid allowing you to `assert_receive` on a tuple with the span.\n\nThis is already setup for you when you `use O11y.TestHelper`.\n```elixir\nsetup [:otel_pid_reporter]\n```","ref":"O11y.TestHelper.html#c:otel_pid_reporter/1"},{"type":"type","title":"O11y.TestHelper.span_record/0","doc":"","ref":"O11y.TestHelper.html#t:span_record/0"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]},"content_type":"text/markdown"}